(axis-common* {:keys [visible major-size minor-size label attribs label-style
label-dist]
:or {visible true major-size 10 minor-size 5}
:as spec})(circle-cell a b c d col)(compute-row-stacking item-range coll)(contour->svg scale-x scale-y project)(contour-matrix w h values)(default-svg-label f)(format-percent x)(labeled-rect-horizontal {:keys [h r label fill min-width base-line]})(lens-axis
{:keys [domain range focus strength major minor] :or {strength 0.5} :as spec})(lens-scale focus strength [d1 d2] [r1 r2])(lin-tick-marks [d1 d2] delta)(linear-axis {:keys [domain range major minor] :as spec})(linear-scale domain range)(log base)(log-axis {:keys [base domain range] :or {base 10} :as spec})(log-scale base [d1 d2 :as domain] [r1 r2 :as range])(log-tick-marks-major base [d1 d2])(log-tick-marks-minor base [d1 d2])(log-ticks-domain base d1 d2)(matrix-2d w h values)(overlap? [a b] [c d])(points->path-segments [p & more])(polar-projection origin)(process-interval-row item-range mapper [d1 d2])(process-points {:keys [x-axis y-axis project]} {:keys [values item-pos shape]})(select-ticks axis minor?)(svg-area-plot {:keys [y-axis project] :as v-spec} {:keys [res] :as d-spec})(svg-axis* {:keys [major minor attribs label-style]}
axis
tick1-fn
tick2-fn
label-fn)(svg-axis-grid2d-cartesian x-axis y-axis {:keys [attribs minor-x minor-y]})(svg-axis-grid2d-polar {:keys [x-axis y-axis origin circle project]
{:keys [attribs minor-x minor-y]} :grid})(svg-bar-plot {:keys [x-axis y-axis project] :or {project vec2}}
{:keys [values attribs shape item-pos interleave offset bar-width]
:or {shape (fn [a b _] (svg/line a b))
item-pos identity
interleave 1
bar-width 0
offset 0}})(svg-contour-plot {:keys [x-axis y-axis project]}
{:keys [matrix attribs levels palette palette-scale
value-domain contour-attribs]
:or {value-domain [0.0 1.0]
palette [[1 1 1]]
palette-scale linear-scale
contour-attribs (constantly nil)}})(svg-heatmap
{:keys [x-axis y-axis project]}
{:keys [matrix value-domain clamp palette palette-scale attribs shape]
:or {value-domain [0.0 1.0]
palette-scale linear-scale
shape (fn* [p1__14804# p2__14805# p3__14806# p4__14807# p5__14808#]
(svg/polygon [p1__14804# p2__14805# p3__14806# p4__14807#]
{:fill p5__14808#}))}
:as d-spec})(svg-heatmap
{:keys [x-axis y-axis project]}
{:keys [matrix value-domain clamp palette palette-scale attribs shape]
:or {value-domain [0.0 1.0]
palette-scale linear-scale
shape (fn* [p1__20502# p2__20503# p3__20504# p4__20505# p5__20506#]
(svg/polygon [p1__20502# p2__20503# p3__20504# p4__20505#]
{:fill p5__20506#}))}
:as d-spec})(svg-line-plot v-spec d-spec)(svg-plot2d-cartesian {:keys [x-axis y-axis grid data] :as opts})(svg-plot2d-polar {:keys [x-axis y-axis grid data origin] :as spec})(svg-radar-plot v-spec {:keys [shape] :or {shape svg/polygon} :as d-spec})(svg-radar-plot-minmax
v-spec
{:keys [item-pos-min item-pos-max shape]
:or {shape (fn* [p1__14761# p2__14762# p3__14763#]
(svg/path (concat p1__14761# [[:Z]] p2__14762# [[:Z]])
p3__14763#))}
:as d-spec})(svg-radar-plot-minmax
v-spec
{:keys [item-pos-min item-pos-max shape]
:or {shape (fn* [p1__20475# p2__20476# p3__20477#]
(svg/path (concat p1__20475# [[:Z]] p2__20476# [[:Z]])
p3__20477#))}
:as d-spec})(svg-scatter-plot v-spec {:keys [attribs shape] :as d-spec})(svg-square r)(svg-stacked-interval-plot
{:keys [x-axis y-axis]}
{:keys [values attribs shape item-range offset]
:or {shape (fn [[a b]] (svg/line a b)) item-range identity offset 0}})(svg-triangle-down w)(svg-triangle-up w)(svg-x-axis-cartesian {:keys [scale major-size minor-size label-dist pos label]
[r1 r2] :range
:as spec})(svg-x-axis-polar {:keys [x-axis project circle origin]})(svg-y-axis-cartesian {:keys [scale major-size minor-size label-dist label-y pos
label]
[r1 r2] :range
:or {label-y 0}
:as spec})(svg-y-axis-polar {:keys [y-axis project]})(total-domain-bounds f & colls)(uniform-domain-points [d1 d2] values)Given a vector of domain bounds and a collection of data values (without domain position), produces a lazy-seq of 2-element vectors representing the values of the original coll uniformly spread over the full domain range, with each of the form: [domain-pos value].
Given a vector of domain bounds and a collection of data values (without domain position), produces a lazy-seq of 2-element vectors representing the values of the original coll uniformly spread over the full domain range, with each of the form: [domain-pos value].
(value-domain-bounds mat)(value-formatter prec)(value-mapper scale-x scale-y)(value-transducer {:keys [cull-domain cull-range scale-x scale-y project shape
item-pos]})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |